@@ -5,6 +5,10 @@ Pydra is a rewrite of the Nipype engine with mapping and joining as
 first-class operations. It forms the core of the Nipype 2.0 ecosystem.
 
 """
+# This call enables pydra.tasks to be used as a namespace package when installed
+# in editable mode. In normal installations it has no effect.
+__path__ = __import__("pkgutil").extend_path(__path__, __name__)
+
 import logging
 
 logger = logging.getLogger("pydra")
