@@ -23,9 +23,10 @@ class SpecInfo:
     name: str
     """A name for the specification."""
     fields: ty.List[ty.Tuple] = attr.ib(factory=list)
-    """List of names of fields (inputs or outputs)."""
+    """List of names of fields (can be inputs or outputs)."""
     bases: ty.Tuple[ty.Type] = attr.ib(factory=tuple)
-    """Keeps track of this specification inheritance."""
+    """Keeps track of specification inheritance.
+       Should be a tuple containing at least one BaseSpec """
 
 
 @attr.s(auto_attribs=True, kw_only=True)
@@ -121,6 +122,19 @@ class Result:
             state["output"] = klass(**state["output"])
         self.__dict__.update(state)
 
+    def get_output_field(self, field_name):
+        """Used in get_values in Workflow
+
+        Parameters
+        ----------
+        field_name : `str`
+            Name of field in LazyField object
+        """
+        if field_name == "all_":
+            return attr.asdict(self.output)
+        else:
+            return getattr(self.output, field_name)
+
 
 @attr.s(auto_attribs=True, kw_only=True)
 class RuntimeSpec:
@@ -193,12 +207,14 @@ class ShellSpec(BaseSpec):
             "copyfile",
             "help_string",
             "mandatory",
+            "readonly",
             "output_field_name",
             "output_file_template",
             "position",
             "requires",
             "separate_ext",
             "xor",
+            "sep",
         }
         # special inputs, don't have to follow rules for standard inputs
         special_input = ["_func", "_graph_checksums"]
@@ -208,22 +224,23 @@ class ShellSpec(BaseSpec):
             mdata = fld.metadata
             # checking keys from metadata
             if set(mdata.keys()) - supported_keys:
-                raise Exception(
+                raise AttributeError(
                     f"only these keys are supported {supported_keys}, but "
                     f"{set(mdata.keys()) - supported_keys} provided"
                 )
             # checking if the help string is provided (required field)
             if "help_string" not in mdata:
-                raise Exception(f"{fld.name} doesn't have help_string field")
-
+                raise AttributeError(f"{fld.name} doesn't have help_string field")
             # assuming that fields with output_file_template shouldn't have default
-            if not fld.default == attr.NOTHING and mdata.get("output_file_template"):
-                raise Exception(
+            if fld.default not in [attr.NOTHING, True, False] and mdata.get(
+                "output_file_template"
+            ):
+                raise AttributeError(
                     "default value should not be set together with output_file_template"
                 )
             # not allowing for default if the field is mandatory
             if not fld.default == attr.NOTHING and mdata.get("mandatory"):
-                raise Exception(
+                raise AttributeError(
                     "default value should not be set when the field is mandatory"
                 )
             # setting default if value not provided and default is available
@@ -246,7 +263,9 @@ class ShellSpec(BaseSpec):
             # checking if the mandatory field is provided
             if getattr(self, fld.name) is attr.NOTHING:
                 if mdata.get("mandatory"):
-                    raise Exception(f"{fld.name} is mandatory, but no value provided")
+                    raise AttributeError(
+                        f"{fld.name} is mandatory, but no value provided"
+                    )
                 else:
                     continue
             names.append(fld.name)
@@ -254,7 +273,7 @@ class ShellSpec(BaseSpec):
             # checking if fields meet the xor and requires are
             if "xor" in mdata:
                 if [el for el in mdata["xor"] if el in names]:
-                    raise Exception(
+                    raise AttributeError(
                         f"{fld.name} is mutually exclusive with {mdata['xor']}"
                     )
 
@@ -269,7 +288,7 @@ class ShellSpec(BaseSpec):
         for nm, required in require_to_check.items():
             required_notfound = [el for el in required if el not in names]
             if required_notfound:
-                raise Exception(f"{nm} requires {required_notfound}")
+                raise AttributeError(f"{nm} requires {required_notfound}")
 
             # TODO: types might be checked here
         self._type_checking()
@@ -277,7 +296,7 @@ class ShellSpec(BaseSpec):
     def _file_check(self, field):
         file = Path(getattr(self, field.name))
         if not file.exists():
-            raise Exception(f"the file from the {field.name} input does not exist")
+            raise AttributeError(f"the file from the {field.name} input does not exist")
 
     def _type_checking(self):
         """Use fld.type to check the types TODO.
@@ -313,7 +332,9 @@ class ShellOutSpec(BaseSpec):
                     if (
                         fld.default is None or fld.default == attr.NOTHING
                     ) and not fld.metadata:  # TODO: is it right?
-                        raise Exception("File has to have default value or metadata")
+                        raise AttributeError(
+                            "File has to have default value or metadata"
+                        )
                     elif not fld.default == attr.NOTHING:
                         additional_out[fld.name] = self._field_defaultvalue(
                             fld, output_dir
@@ -329,7 +350,7 @@ class ShellOutSpec(BaseSpec):
     def _field_defaultvalue(self, fld, output_dir):
         """Collect output file if the default value specified."""
         if not isinstance(fld.default, (str, Path)):
-            raise Exception(
+            raise AttributeError(
                 f"{fld.name} is a File, so default value "
                 f"should be a string or a Path, "
                 f"{fld.default} provided"
@@ -344,7 +365,7 @@ class ShellOutSpec(BaseSpec):
             if default.exists():
                 return default
             else:
-                raise Exception(f"file {default} does not exist")
+                raise AttributeError(f"file {default} does not exist")
         else:
             all_files = list(Path(default.parent).expanduser().glob(default.name))
             if len(all_files) > 1:
@@ -352,7 +373,7 @@ class ShellOutSpec(BaseSpec):
             elif len(all_files) == 1:
                 return all_files[0]
             else:
-                raise Exception(f"no file matches {default.name}")
+                raise AttributeError(f"no file matches {default.name}")
 
     def _field_metadata(self, fld, inputs, output_dir):
         """Collect output file if metadata specified."""
@@ -492,24 +513,26 @@ class LazyField:
                 if len(result) and isinstance(result[0], list):
                     results_new = []
                     for res_l in result:
-                        if self.field == "all_":
-                            res_l_new = [attr.asdict(res.output) for res in res_l]
-                        else:
-                            res_l_new = [
-                                getattr(res.output, self.field) for res in res_l
-                            ]
+                        res_l_new = []
+                        for res in res_l:
+                            if res.errored:
+                                raise ValueError("Error from get_value")
+                            else:
+                                res_l_new.append(res.get_output_field(self.field))
                         results_new.append(res_l_new)
                     return results_new
                 else:
-                    if self.field == "all_":
-                        return [attr.asdict(res.output) for res in result]
-                    else:
-                        return [getattr(res.output, self.field) for res in result]
+                    results_new = []
+                    for res in result:
+                        if res.errored:
+                            raise ValueError("Error from get_value")
+                        else:
+                            results_new.append(res.get_output_field(self.field))
+                    return results_new
             else:
-                if self.field == "all_":
-                    return attr.asdict(result.output)
-                else:
-                    return getattr(result.output, self.field)
+                if result.errored:
+                    raise ValueError("Error from get_value")
+                return result.get_output_field(self.field)
 
 
 def donothing(*args, **kwargs):
