@@ -5,7 +5,6 @@ packaged separately.
 To create a task package, please fork the `pydra-tasks-template
 <https://github.com/nipype/pydra-tasks-template>`__.
 """
-try:
-    __import__("pkg_resources").declare_namespace(__name__)
-except ImportError:
-    pass  # must not have setuptools
+# This call enables pydra.tasks to be used as a namespace package when installed
+# in editable mode. In normal installations it has no effect.
+__path__ = __import__("pkgutil").extend_path(__path__, __name__)
